@@ -14,9 +14,9 @@ from shutil import copy2
 from email.utils import formatdate
 from enum import Enum
 
-__version__ = '2.202002'
+__version__ = '2.202003'
 __dhlib__ = '/usr/share/debhelper/dh_make'
-policy_version = '4.5.0'
+policy_version = '4.5.1'
 
 
 def check_dhlib_path():
@@ -392,19 +392,19 @@ def get_logname():
 def get_username():
 
     username = os.environ.get('DEBFULLNAME')
-    if username is not None and username != '':
+    if username:
         return username
 
     logname = get_logname()
-    if logname != '':
+    if logname:
         username = pwd.getpwnam(logname).pw_gecos.rsplit(',')[0]
-        if username != '':
+        if username:
             return username
 
     # NIS/ypmatch
     try:
         username = nis.match(logname, 'passwd.byname').split(':')[4]
-        if username != '':
+        if username:
             return username
     except nis.error:
         pass
@@ -833,7 +833,8 @@ def do_debianize(args, subs):
 
     rename_package_files(subs['PACKAGE'])
 
-    os.chmod('rules', 0o755)
+    if os.path.exists('rules'):
+        os.chmod('rules', 0o755)
 
     print('Done. Please edit the files in the debian/ subdirectory now.\n')
     if args.package_class == PackageClass.library:
